@@ -4,7 +4,7 @@ use warnings;
 use base qw{Pod::Parser};
 
 # Set our version
-our $VERSION = '0.0001';
+our $VERSION = '0.0002';
 
 # Hold data for our pending statement
 my $info = {};
@@ -61,7 +61,8 @@ sub _instance {
 
 sub _process {# pos file
     my ($class, $file,) = @_;
-    return unless $file;
+    return 
+        unless $file;
     $file .='.pm'
         if $file =~ s/::/\//g;
     $class->SUPER::new->parse_from_file($file);
@@ -262,7 +263,7 @@ sub template {
 
 =head1 VERSION
 
-0.0001
+0.0002
 
 =head1 NAME
 
@@ -300,7 +301,30 @@ DBIx::POS::Template - is a fork of L<DBIx::POS>. Define a dictionary of SQL stat
 
   =cut
 
+Or inheritance syntax
 
+  package FooPOS;
+  use base qw{DBIx::POS::Template};
+  
+  sub new { shift->SUPER::new(__FILE__); }
+  
+  =pod
+  
+  =name ...
+  
+  =desc ...
+  
+  ...
+  
+  =cut
+  
+  1;
+
+Then
+
+  use FooPos;
+  my $pos = FooPOS->new;# pos-file is the self module
+  
 
 =head1 DESCRIPTION
 
